@@ -1,10 +1,10 @@
 from json import *
 
-def read_file(filename):
+def load_file(filename):
     with open(filename, "r") as f:
         return json.loads(f.read())
 
 
-def write_file(filename, content):
+def dump_file(filename, content):
     with open(filename, "w") as f:
-        f.write(json.dumps(content))
\ No newline at end of file
+        f.write(json.dumps(content))
